listOperations method

Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns UNIMPLEMENTED.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

Future<ListOperationsResponse> listOperations(
  ListOperationsRequest request,
) async {
  final url = _endPoint.replace(
    path: '/v1/${request.name}',
    queryParameters: {
      if (request.filter case final $1 when $1.isNotDefault) 'filter': $1,
      if (request.pageSize case final $1 when $1.isNotDefault)
        'pageSize': '${$1}',
      if (request.pageToken case final $1 when $1.isNotDefault)
        'pageToken': $1,
      if (request.returnPartialSuccess case final $1 when $1.isNotDefault)
        'returnPartialSuccess': '${$1}',
    },
  );
  final response = await _client.get(url);
  return ListOperationsResponse.fromJson(response);
}