FakeOperations class base

Testing fake for Operations.

Implemented types

Constructors

FakeOperations({Future<ListOperationsResponse> listOperations(ListOperationsRequest request)?, Future<Operation<ProtoMessage, ProtoMessage>> getOperation(GetOperationRequest request)?, Future<void> deleteOperation(DeleteOperationRequest request)?, Future<void> cancelOperation(CancelOperationRequest request)?})

Properties

hashCode int
The hash code for this object.
no setterinherited
isClosed bool
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancelOperation(CancelOperationRequest request) Future<void>
Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED.
override
close() → void
Closes the client and cleans up any resources associated with it.
override
deleteOperation(DeleteOperationRequest request) Future<void>
Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
override
getOperation(GetOperationRequest request) Future<Operation<ProtoMessage, ProtoMessage>>
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
override
listOperations(ListOperationsRequest request) Future<ListOperationsResponse>
Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns UNIMPLEMENTED.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited