cancelOperation method

  1. @override
Future<void> cancelOperation(
  1. CancelOperationRequest request
)
override

Starts asynchronous cancellation on a long-running operation. The server makes a best effort to cancel the operation, but success is not guaranteed. If the server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED. Clients can use Operations.GetOperation or other methods to check whether the cancellation succeeded or whether the operation completed despite cancellation. On successful cancellation, the operation is not deleted; instead, it becomes an operation with an Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<void> cancelOperation(CancelOperationRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_cancelOperation case final cancelOperation?) {
    return cancelOperation(request);
  }
  throw UnsupportedError('cancelOperation');
}