deleteOperation method

  1. @override
Future<void> deleteOperation(
  1. DeleteOperationRequest request
)
override

Deletes a long-running operation. This method indicates that the client is no longer interested in the operation result. It does not cancel the operation. If the server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<void> deleteOperation(DeleteOperationRequest request) async {
  if (isClosed) throw StateError('Service is closed');

  if (_deleteOperation case final deleteOperation?) {
    return deleteOperation(request);
  }
  throw UnsupportedError('deleteOperation');
}