listOperations method

  1. @override
Future<ListOperationsResponse> listOperations(
  1. ListOperationsRequest request
)
override

Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns UNIMPLEMENTED.

Throws a http.ClientException if there were problems communicating with the API service. Throws a ServiceException if the API method failed for any reason.

Implementation

@override
Future<ListOperationsResponse> listOperations(
  ListOperationsRequest request,
) async {
  if (isClosed) throw StateError('Service is closed');

  if (_listOperations case final listOperations?) {
    return listOperations(request);
  }
  throw UnsupportedError('listOperations');
}