longrunning library
The Google Cloud client for the Long Running Operations API.
Defines types and an abstract service to handle long-running operations.
Long-running operations are a common pattern to handle methods that may take
a significant amount of time to execute. Many Google APIs return an Operation
message (defined in this package) that are roughly analogous to a future. The
operation will eventually complete, though it may still return an error on
completion. The client libraries provide helpers to simplify polling of these
operations.
Classes
- CancelOperationRequest
-
The request message for
Operations.CancelOperation. - DeleteOperationRequest
-
The request message for
Operations.DeleteOperation. - GetOperationRequest
-
The request message for
Operations.GetOperation. - ListOperationsRequest
-
The request message for
Operations.ListOperations. - ListOperationsResponse
-
The response message for
Operations.ListOperations. -
Operation<
T extends ProtoMessage, S extends ProtoMessage> - This resource represents a long-running operation that is the result of a network API call.
-
OperationHelper<
T extends ProtoMessage, S extends ProtoMessage> - This helper class is used to pull typed messages out of the Operation.response and Operation.metadata fields in order to populate the typed Operation.responseAsMessage and Operation.metadataAsMessage fields.
- OperationInfo
- A message representing the message types used by a long-running operation.
- Operations
- Manages long-running operations with an API service.
- WaitOperationRequest
-
The request message for
Operations.WaitOperation.
Exceptions / Errors
- BadGatewayException
- Exception thrown when the server returns a "502 Bad Gateway" response.
- BadRequestException
- Exception thrown when the server returns a "400 Bad Request" response.
- CancelledException
- Exception thrown when the server returns a "499 Cancelled" response.
- ConfigurationException
- Exception thrown when a method is called without correct configuration.
- ConflictException
- Exception thrown when the server returns a "409 Conflict" response.
- ForbiddenException
- Exception thrown when the server returns a "403 Forbidden" response.
- GatewayTimeoutException
- Exception thrown when the server returns a "504 Gateway Timeout" response.
- InternalServerErrorException
- Exception thrown when the server returns a "500 Internal Server Error" response.
- LengthRequiredException
- Exception thrown when the server returns a "411 Length Required" response.
- MethodNotAllowedException
- Exception thrown when the server returns a "405 Method Not Allowed" response.
- NotFoundException
- Exception thrown when the server returns a "404 Not Found" response.
- NotImplementedException
- Exception thrown when the server returns a "501 Not Implemented" response.
- NotModifiedException
- Exception thrown when the server returns a "304 Not Modified" response.
- PreconditionFailedException
- Exception thrown when the server returns a "412 Precondition Failed" response.
- RequestRangeNotSatisfiableException
- Exception thrown when the server returns a "416 Request Range Not Satisfiable" response.
- RequestTimeoutException
- Exception thrown when the server returns a "408 Request Timeout" response.
- ServiceException
- Exception thrown when an API call fails.
- Exception thrown when the server returns a "503 Service Unavailable" response.
- TooManyRequestsException
- Exception thrown when the server returns a "429 Too Many Requests" response.
- Exception thrown when the server returns a "401 Unauthorized" response.